"""
:authors: Peopl3s
:license: Apache License, Version 2.0, see LICENSE file

:copyright: (c) 2021 Peopl3s
"""

from .clubhouse import (Machine,)


__author__ = 'Peopl3s'
__version__ = '0.9.9'
__email__ = 'peoplesdreamer@gmail.com'